# -*- coding: UTF-8 -*-
#/**
# * Software Name : pycrate
# * Version : 0.4
# *
# * Copyright 2018. Benoit Michau. P1sec.
# *
# * This library is free software; you can redistribute it and/or
# * modify it under the terms of the GNU Lesser General Public
# * License as published by the Free Software Foundation; either
# * version 2.1 of the License, or (at your option) any later version.
# *
# * This library is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# * Lesser General Public License for more details.
# *
# * You should have received a copy of the GNU Lesser General Public
# * License along with this library; if not, write to the Free Software
# * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
# * MA 02110-1301  USA
# *
# *--------------------------------------------------------
# * File Name : pycrate_gmr1_csn1/downlink_rlc_mac_control_message.py
# * Created : 2023-10-24
# * Authors : Benoit Michau
# *--------------------------------------------------------
#*/
# specification: ETSI TS 101 376-04-12
# section: 11.2.0.1        Downlink RLC/MAC messages
# top-level object: Downlink RLC/MAC control message

# external references
from pycrate_gmr1_csn1.packet_uplink_ack_nack_type_2_message_content import packet_uplink_ack_nack_type_2_message_content
from pycrate_gmr1_csn1.packet_measurement_order_message_content import packet_measurement_order_message_content
from pycrate_gmr1_csn1.packet_pdch_release_message_content import packet_pdch_release_message_content
from pycrate_gmr1_csn1.packet_downlink_assignment_message_content import packet_downlink_assignment_message_content
from pycrate_gmr1_csn1.multiple_tbf_downlink_assignment_message_content import multiple_tbf_downlink_assignment_message_content
from pycrate_gmr1_csn1.packet_downlink_assignment_type_2_message_content import packet_downlink_assignment_type_2_message_content
from pycrate_gmr1_csn1.packet_downlink_dummy_control_block_message_content import packet_downlink_dummy_control_block_message_content
from pycrate_gmr1_csn1.packet_dch_assignment_message_content import packet_dch_assignment_message_content
from pycrate_gmr1_csn1.packet_gmprs_resume_response_message_content import packet_gmprs_resume_response_message_content
from pycrate_gmr1_csn1.packet_link_control_message_content import packet_link_control_message_content
from pycrate_gmr1_csn1.packet_dch_uplink_ack_nack_message_content import packet_dch_uplink_ack_nack_message_content
from pycrate_gmr1_csn1.multiple_tbf_timeslot_reconfigure_message_content import multiple_tbf_timeslot_reconfigure_message_content
from pycrate_gmr1_csn1.multiple_tbf_uplink_assignment_message_content import multiple_tbf_uplink_assignment_message_content
from pycrate_gmr1_csn1.packet_tbf_release_message_content import packet_tbf_release_message_content
from pycrate_gmr1_csn1.packet_paging_request_message_content import packet_paging_request_message_content
from pycrate_gmr1_csn1.packet_access_reject_message_content import packet_access_reject_message_content
from pycrate_gmr1_csn1.packet_uplink_talk_burst_control_response_message_content import packet_uplink_talk_burst_control_response_message_content
from pycrate_gmr1_csn1.packet_uplink_assignment_message_content import packet_uplink_assignment_message_content
from pycrate_gmr1_csn1.packet_tbf_assignment_type_2_message_content import packet_tbf_assignment_type_2_message_content
from pycrate_gmr1_csn1.pdch_organization_message_content import pdch_organization_message_content
from pycrate_gmr1_csn1.packet_uplink_assignment_type_2_message_content import packet_uplink_assignment_type_2_message_content
from pycrate_gmr1_csn1.packet_timeslot_reconfigure_message_content import packet_timeslot_reconfigure_message_content
from pycrate_gmr1_csn1.packet_cell_change_order_message_content import packet_cell_change_order_message_content
from pycrate_gmr1_csn1.packet_tbf_release_type_2_message_content import packet_tbf_release_type_2_message_content
from pycrate_gmr1_csn1.packet_uplink_ack_nack_message_content import packet_uplink_ack_nack_message_content
from pycrate_gmr1_csn1.physical_information_message_content import physical_information_message_content
from pycrate_gmr1_csn1.packet_link_adaptation_control_message_content import packet_link_adaptation_control_message_content

# code automatically generated by pycrate_csn1
# change object type with type=CSN1T_BSTR (default type is CSN1T_UINT) in init
# add dict for value interpretation with dic={...} in CSN1Bit init
# add dict for key interpretation with kdic={...} in CSN1Alt init

from pycrate_csn1.csnobj import *

downlink_rlc_mac_control_message = CSN1Alt(name='downlink_rlc_mac_control_message', alt={
  '000001': ('message_type', [
  CSN1Ref(obj=packet_cell_change_order_message_content)]),
  '000010': ('message_type', [
  CSN1Ref(obj=packet_downlink_assignment_message_content)]),
  '000011': ('message_type', [
  CSN1Ref(obj=packet_measurement_order_message_content)]),
  '000101': ('message_type', [
  CSN1Ref(obj=packet_link_control_message_content)]),
  '000110': ('message_type', [
  CSN1Ref(obj=packet_link_adaptation_control_message_content)]),
  '000111': ('message_type', [
  CSN1Ref(obj=packet_timeslot_reconfigure_message_content)]),
  '001000': ('message_type', [
  CSN1Ref(obj=packet_tbf_release_message_content)]),
  '001001': ('message_type', [
  CSN1Ref(obj=packet_uplink_ack_nack_message_content)]),
  '001010': ('message_type', [
  CSN1Ref(obj=packet_uplink_assignment_message_content)]),
  '001110': ('message_type', [
  CSN1Ref(obj=packet_dch_assignment_message_content)]),
  '001111': ('message_type', [
  CSN1Ref(obj=multiple_tbf_downlink_assignment_message_content)]),
  '010000': ('message_type', [
  CSN1Ref(obj=multiple_tbf_uplink_assignment_message_content)]),
  '010001': ('message_type', [
  CSN1Ref(obj=multiple_tbf_timeslot_reconfigure_message_content)]),
  '010010': ('message_type', [
  CSN1Ref(obj=physical_information_message_content)]),
  '010011': ('message_type', [
  CSN1Ref(obj=packet_tbf_assignment_type_2_message_content)]),
  '011101': ('message_type', [
  CSN1Ref(obj=pdch_organization_message_content)]),
  '011110': ('message_type', [
  CSN1Ref(obj=packet_gmprs_resume_response_message_content)]),
  '011111': ('message_type', [
  CSN1Ref(obj=packet_dch_uplink_ack_nack_message_content)]),
  '100001': ('message_type', [
  CSN1Ref(obj=packet_access_reject_message_content)]),
  '100010': ('message_type', [
  CSN1Ref(obj=packet_paging_request_message_content)]),
  '100011': ('message_type', [
  CSN1Ref(obj=packet_pdch_release_message_content)]),
  '100101': ('message_type', [
  CSN1Ref(obj=packet_downlink_dummy_control_block_message_content)]),
  '100110': ('message_type', [
  CSN1Ref(obj=packet_uplink_talk_burst_control_response_message_content)]),
  '101000': ('message_type', [
  CSN1Ref(obj=packet_tbf_release_type_2_message_content)]),
  '101001': ('message_type', [
  CSN1Ref(obj=packet_uplink_ack_nack_type_2_message_content)]),
  '101010': ('message_type', [
  CSN1Ref(obj=packet_uplink_assignment_type_2_message_content)]),
  '111100': ('message_type', [
  CSN1Ref(obj=packet_downlink_assignment_type_2_message_content)])})

