# -*- coding: UTF-8 -*-
#/**
# * Software Name : pycrate
# * Version : 0.4
# *
# * Copyright 2018. Benoit Michau. P1sec.
# *
# * This library is free software; you can redistribute it and/or
# * modify it under the terms of the GNU Lesser General Public
# * License as published by the Free Software Foundation; either
# * version 2.1 of the License, or (at your option) any later version.
# *
# * This library is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# * Lesser General Public License for more details.
# *
# * You should have received a copy of the GNU Lesser General Public
# * License along with this library; if not, write to the Free Software
# * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
# * MA 02110-1301  USA
# *
# *--------------------------------------------------------
# * File Name : pycrate_gmr1_csn1/downlink_rrc_messages.py
# * Created : 2023-10-24
# * Authors : Benoit Michau
# *--------------------------------------------------------
#*/
# specification: ETSI TS 101 376-04-13
# section: 9.2.1.2         Downlink RRC messages
# top-level object: Downlink RRC messages

# external references
from pycrate_gmr1_csn1.signalling_connection_release_message_content import signalling_connection_release_message_content
from pycrate_gmr1_csn1.rrc_status_message_content import rrc_status_message_content
from pycrate_gmr1_csn1.rrc_connection_setup_message_content import rrc_connection_setup_message_content
from pycrate_gmr1_csn1.downlink_direct_transfer_message_content import downlink_direct_transfer_message_content
from pycrate_gmr1_csn1.cell_update_confirm_message_content import cell_update_confirm_message_content
from pycrate_gmr1_csn1.lcs_downlink_information_message_content import lcs_downlink_information_message_content
from pycrate_gmr1_csn1.rab_upper_layer_reconfiguration_message_content import rab_upper_layer_reconfiguration_message_content
from pycrate_gmr1_csn1.mes_capability_enquiry_message_content import mes_capability_enquiry_message_content
from pycrate_gmr1_csn1.radio_bearer_release_message_content import radio_bearer_release_message_content
from pycrate_gmr1_csn1.mes_capability_information_confirm_message_content import mes_capability_information_confirm_message_content
from pycrate_gmr1_csn1.security_mode_command_message_content import security_mode_command_message_content
from pycrate_gmr1_csn1.rrc_connection_release_message_content import rrc_connection_release_message_content
from pycrate_gmr1_csn1.uplink_rrc_messages import default_downlink_message_content
from pycrate_gmr1_csn1.rab_binding_response_message_content import rab_binding_response_message_content
from pycrate_gmr1_csn1.downlink_key_exchange_message_content import downlink_key_exchange_message_content
from pycrate_gmr1_csn1.radio_bearer_setup_message_content import radio_bearer_setup_message_content
from pycrate_gmr1_csn1.radio_bearer_reconfiguration_message_content import radio_bearer_reconfiguration_message_content
from pycrate_gmr1_csn1.geran_mobility_information_message_content import geran_mobility_information_message_content
from pycrate_gmr1_csn1.position_report_request_message_content import position_report_request_message_content
from pycrate_gmr1_csn1.gra_update_confirm_message_content import gra_update_confirm_message_content
from pycrate_gmr1_csn1.geran_iu_mode_dtm_reject_message_content import geran_iu_mode_dtm_reject_message_content

# code automatically generated by pycrate_csn1
# change object type with type=CSN1T_BSTR (default type is CSN1T_UINT) in init
# add dict for value interpretation with dic={...} in CSN1Bit init
# add dict for key interpretation with kdic={...} in CSN1Alt init

from pycrate_csn1.csnobj import *

spare_bit = CSN1Bit(name='spare_bit')
Spare_bit = spare_bit
Spare_Bit = spare_bit

downlink_rrc_messages = CSN1List(name='downlink_rrc_messages', list=[
  CSN1Alt(alt={
    '00000000': ('message_type', [
    CSN1Ref(obj=cell_update_confirm_message_content)]),
    '00000010': ('message_type', [
    CSN1Ref(obj=downlink_direct_transfer_message_content)]),
    '00000011': ('message_type', [
    CSN1Ref(obj=rab_binding_response_message_content)]),
    '00000100': ('message_type', [
    CSN1Ref(obj=geran_mobility_information_message_content)]),
    '00000101': ('message_type', [
    CSN1Ref(obj=gra_update_confirm_message_content)]),
    '00001010': ('message_type', [
    CSN1Ref(obj=lcs_downlink_information_message_content)]),
    '00001100': ('message_type', [
    CSN1Ref(obj=mes_capability_enquiry_message_content)]),
    '00001101': ('message_type', [
    CSN1Ref(obj=mes_capability_information_confirm_message_content)]),
    '00001110': ('message_type', [
    CSN1Ref(obj=radio_bearer_reconfiguration_message_content)]),
    '00001111': ('message_type', [
    CSN1Ref(obj=radio_bearer_setup_message_content)]),
    '00010000': ('message_type', [
    CSN1Ref(obj=radio_bearer_release_message_content)]),
    '00010010': ('message_type', [
    CSN1Ref(obj=rrc_connection_release_message_content)]),
    '00010011': ('message_type', [
    CSN1Ref(obj=rrc_connection_setup_message_content)]),
    '00010100': ('message_type', [
    CSN1Ref(obj=rrc_status_message_content)]),
    '00010101': ('message_type', [
    CSN1Ref(obj=security_mode_command_message_content)]),
    '00010110': ('message_type', [
    CSN1Ref(obj=signalling_connection_release_message_content)]),
    '00010111': ('message_type', [
    CSN1Ref(obj=geran_iu_mode_dtm_reject_message_content)]),
    '00011000': ('message_type', [
    CSN1Ref(obj=downlink_key_exchange_message_content)]),
    '00011100': ('message_type', [
    CSN1Ref(obj=rab_upper_layer_reconfiguration_message_content)]),
    '00011101': ('message_type', [
    CSN1Ref(obj=position_report_request_message_content)])}),
  CSN1Ref(obj=spare_bit, num=-1)])

