# -*- coding: UTF-8 -*-
#/**
# * Software Name : pycrate
# * Version : 0.4
# *
# * Copyright 2018. Benoit Michau. P1sec.
# *
# * This library is free software; you can redistribute it and/or
# * modify it under the terms of the GNU Lesser General Public
# * License as published by the Free Software Foundation; either
# * version 2.1 of the License, or (at your option) any later version.
# *
# * This library is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# * Lesser General Public License for more details.
# *
# * You should have received a copy of the GNU Lesser General Public
# * License along with this library; if not, write to the Free Software
# * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
# * MA 02110-1301  USA
# *
# *--------------------------------------------------------
# * File Name : pycrate_gmr1_csn1/gbch_information_message.py
# * Created : 2023-10-24
# * Authors : Benoit Michau
# *--------------------------------------------------------
#*/
# specification: ETSI TS 101 376-04-12, release 1
# section: 10.1.46        GBCH information
# top-level object: GBCH Information Message



# code automatically generated by pycrate_csn1
# change object type with type=CSN1T_BSTR (default type is CSN1T_UINT) in init
# add dict for value interpretation with dic={...} in CSN1Bit init
# add dict for key interpretation with kdic={...} in CSN1Alt init

from pycrate_csn1.csnobj import *

gbch_information_type_1 = CSN1List(name='gbch_information_type_1', list=[
  CSN1Bit(name='gps_time', bit=40),
  CSN1Bit(name='curve_fit_time', bit=40),
  CSN1Bit(name='spare'),
  CSN1Bit(name='frame_number', bit=19)])

gbch_information_type_2 = CSN1List(name='gbch_information_type_2', list=[
  CSN1Bit(name='visibility_list_part_1', bit=60),
  CSN1Bit(name='dopplers_part_1', bit=40)])

gbch_information_type_3 = CSN1List(name='gbch_information_type_3', list=[
  CSN1Bit(name='visibility_list_repetition_part_1', bit=60),
  CSN1Bit(name='dopplers_repetition_part_1', bit=40)])

gbch_information_type_4 = CSN1List(name='gbch_information_type_4', list=[
  CSN1Bit(name='dopplers_part_2', bit=56),
  CSN1Bit(name='code_phases_part_1', bit=44)])

gbch_information_type_5 = CSN1List(name='gbch_information_type_5', list=[
  CSN1Bit(name='visibility_list_part_2', bit=12),
  CSN1Bit(name='code_phases_part_2', bit=88)])

gbch_information_type_6 = CSN1List(name='gbch_information_type_6', list=[
  CSN1Bit(name='dopplers_repetition_part_2', bit=56),
  CSN1Bit(name='code_phases_part_3', bit=44)])

gbch_information_type_7 = CSN1List(name='gbch_information_type_7', list=[
  CSN1Bit(name='visibility_list_repetition_part_2', bit=12),
  CSN1Bit(name='code_phases_part_4', bit=88)])

gbch_information_type_8 = CSN1List(name='gbch_information_type_8', list=[
  CSN1Bit(name='x0', bit=24),
  CSN1Bit(name='vx0', bit=18),
  CSN1Bit(name='vx2', bit=8),
  CSN1Bit(name='y0', bit=24),
  CSN1Bit(name='vy0', bit=18),
  CSN1Bit(name='vy2', bit=8)])

gbch_information_type_9 = CSN1List(name='gbch_information_type_9', list=[
  CSN1Bit(name='vx1', bit=13),
  CSN1Bit(name='vy1', bit=13),
  CSN1Bit(name='z0', bit=24),
  CSN1Bit(name='vz0', bit=18),
  CSN1Bit(name='vz1', bit=13),
  CSN1Bit(name='vz2', bit=8),
  CSN1Bit(name='af1', bit=11)])

gbch_information_message = CSN1List(name='gbch_information_message', list=[
  CSN1Bit(name='protocol_escape'),
  CSN1Bit(name='gbch_sequence_number', bit=2),
  CSN1Alt(alt={
    '00000': ('', [
    CSN1Ref(obj=gbch_information_type_1)]),
    '00001': ('', [
    CSN1Ref(obj=gbch_information_type_2)]),
    '00010': ('', [
    CSN1Ref(obj=gbch_information_type_4)]),
    '00011': ('', [
    CSN1Ref(obj=gbch_information_type_5)]),
    '00100': ('', [
    CSN1Ref(name='sat_1', obj=gbch_information_type_8)]),
    '00101': ('', [
    CSN1Ref(name='sat_1', obj=gbch_information_type_9)]),
    '00110': ('', [
    CSN1Ref(name='sat_2', obj=gbch_information_type_8)]),
    '00111': ('', [
    CSN1Ref(name='sat_2', obj=gbch_information_type_9)]),
    '01000': ('', [
    CSN1Ref(name='sat_3', obj=gbch_information_type_8)]),
    '01001': ('', [
    CSN1Ref(name='sat_3', obj=gbch_information_type_9)]),
    '01010': ('', [
    CSN1Ref(name='sat_4', obj=gbch_information_type_8)]),
    '01011': ('', [
    CSN1Ref(name='sat_4', obj=gbch_information_type_9)]),
    '01100': ('', [
    CSN1Ref(name='sat_5', obj=gbch_information_type_8)]),
    '01101': ('', [
    CSN1Ref(name='sat_5', obj=gbch_information_type_9)]),
    '01110': ('', [
    CSN1Ref(name='sat_6', obj=gbch_information_type_8)]),
    '01111': ('', [
    CSN1Ref(name='sat_6', obj=gbch_information_type_9)]),
    '10000': ('', [
    CSN1Ref(obj=gbch_information_type_1)]),
    '10001': ('', [
    CSN1Ref(obj=gbch_information_type_3)]),
    '10010': ('', [
    CSN1Ref(obj=gbch_information_type_6)]),
    '10011': ('', [
    CSN1Ref(obj=gbch_information_type_7)]),
    '10100': ('', [
    CSN1Ref(name='sat_7', obj=gbch_information_type_8)]),
    '10101': ('', [
    CSN1Ref(name='sat_7', obj=gbch_information_type_9)]),
    '10110': ('', [
    CSN1Ref(name='sat_8', obj=gbch_information_type_8)]),
    '10111': ('', [
    CSN1Ref(name='sat_8', obj=gbch_information_type_9)]),
    '11000': ('', [
    CSN1Ref(name='sat_9', obj=gbch_information_type_8)]),
    '11001': ('', [
    CSN1Ref(name='sat_9', obj=gbch_information_type_9)]),
    '11010': ('', [
    CSN1Ref(name='sat_10', obj=gbch_information_type_8)]),
    '11011': ('', [
    CSN1Ref(name='sat_10', obj=gbch_information_type_9)]),
    '11100': ('', [
    CSN1Ref(name='sat_11', obj=gbch_information_type_8)]),
    '11101': ('', [
    CSN1Ref(name='sat_11', obj=gbch_information_type_9)]),
    '11110': ('', [
    CSN1Ref(name='sat_12', obj=gbch_information_type_8)]),
    '11111': ('', [
    CSN1Ref(name='sat_12', obj=gbch_information_type_9)])})])

