# -*- coding: UTF-8 -*-
#/**
# * Software Name : pycrate
# * Version : 0.4
# *
# * Copyright 2018. Benoit Michau. P1sec.
# *
# * This library is free software; you can redistribute it and/or
# * modify it under the terms of the GNU Lesser General Public
# * License as published by the Free Software Foundation; either
# * version 2.1 of the License, or (at your option) any later version.
# *
# * This library is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# * Lesser General Public License for more details.
# *
# * You should have received a copy of the GNU Lesser General Public
# * License along with this library; if not, write to the Free Software
# * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
# * MA 02110-1301  USA
# *
# *--------------------------------------------------------
# * File Name : pycrate_gmr1_csn1/packet_uplink_assignment_message_content.py
# * Created : 2023-10-24
# * Authors : Benoit Michau
# *--------------------------------------------------------
#*/
# specification: ETSI TS 101 376-04-12
# section: 11.2.22 Packet uplink assignment (A/Gb mode only)
# top-level object: Packet Uplink Assignment message content

# external references
from pycrate_gmr1_csn1.packet_link_synchronization_ie import packet_link_synchronization_ie
from pycrate_gmr1_csn1.global_tfi_ie import global_tfi_ie
from pycrate_gmr1_csn1.frequency_parameters_ie import frequency_parameters_ie
from pycrate_gmr1_csn1.padding_bits import padding_bits

# code automatically generated by pycrate_csn1
# change object type with type=CSN1T_BSTR (default type is CSN1T_UINT) in init
# add dict for value interpretation with dic={...} in CSN1Bit init
# add dict for key interpretation with kdic={...} in CSN1Alt init

from pycrate_csn1.csnobj import *

extension = CSN1Val(name='extension', val='null')

reserved = CSN1Val(name='reserved', val='null')

dynamic_allocation_struct = CSN1List(name='dynamic_allocation_struct', list=[
  CSN1Bit(name='reserved'),
  CSN1Bit(name='reserved'),
  CSN1Bit(name='uplink_tfi_assignment', bit=7),
  CSN1Bit(name='reserved'),
  CSN1Bit(name='reserved', bit=5),
  CSN1Bit(name='channel_mcs_command_pnb_5_12', bit=4),
  CSN1Bit(name='mac_slot_allocation', bit=8),
  CSN1Bit(name='reserved', bit=3),
  CSN1Bit(name='usf', bit=6)])

packet_uplink_assignment_message_content = CSN1List(name='packet_uplink_assignment_message_content', list=[
  CSN1Alt(alt={
    '0': ('', [
    CSN1Bit(name='tlli', bit=32)]),
    '10': ('', [
    CSN1Ref(name='global_tfi', obj=global_tfi_ie)]),
    '110': ('', [
    CSN1Bit(name='reserved', bit=16)])}),
  CSN1Bit(name='rid', bit=2),
  CSN1List(list=[
    CSN1Val(name='', val='0'),
    CSN1List(list=[
      CSN1Bit(name='channel_mcs_command', bit=4),
      CSN1Ref(name='packet_link_synchronization', obj=packet_link_synchronization_ie),
      CSN1Ref(name='frequency_parameters', obj=frequency_parameters_ie),
      CSN1Alt(alt={
        '0': ('', [
        CSN1Ref(name='dynamic_allocation', obj=dynamic_allocation_struct)]),
        '10': ('', [
        CSN1Ref(obj=reserved)]),
        '110': ('', [
        CSN1Ref(obj=reserved)]),
        '1110': ('', [
        CSN1Ref(obj=extension)])}),
      CSN1Ref(obj=padding_bits)])])])

