# -*- coding: UTF-8 -*-
#/**
# * Software Name : pycrate
# * Version : 0.4
# *
# * Copyright 2018. Benoit Michau. P1sec.
# *
# * This library is free software; you can redistribute it and/or
# * modify it under the terms of the GNU Lesser General Public
# * License as published by the Free Software Foundation; either
# * version 2.1 of the License, or (at your option) any later version.
# *
# * This library is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# * Lesser General Public License for more details.
# *
# * You should have received a copy of the GNU Lesser General Public
# * License along with this library; if not, write to the Free Software
# * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
# * MA 02110-1301  USA
# *
# *--------------------------------------------------------
# * File Name : pycrate_gmr1_csn1/pdcp_info_ie.py
# * Created : 2023-10-24
# * Authors : Benoit Michau
# *--------------------------------------------------------
#*/
# specification: ETSI TS 101 376-04-13
# section: 9.3.60        PDCP Info
# top-level object: PDCP Info IE

# external references
from pycrate_gmr1_csn1.data_compression_parameter_ie import data_compression_parameter_ie

# code automatically generated by pycrate_csn1
# change object type with type=CSN1T_BSTR (default type is CSN1T_UINT) in init
# add dict for value interpretation with dic={...} in CSN1Bit init
# add dict for key interpretation with kdic={...} in CSN1Alt init

from pycrate_csn1.csnobj import *

header_compression_information_struct = CSN1List(name='header_compression_information_struct', list=[
  CSN1Bit(name='header_compression_information_struct_length', bit=14),
  CSN1Alt(alt={
    '000': ('header_compression_according_to_ietf_rfc_2507', [
    CSN1Bit(name='f_max_period', bit=16),
    CSN1Bit(name='f_max_time', bit=8),
    CSN1Bit(name='max_header', bit=16),
    CSN1Bit(name='tcp_space', bit=8),
    CSN1Bit(name='non_tcp_space', bit=16),
    CSN1Bit(name='expect_reordering')]),
    '001': ('header_compression_according_to_ietf_rfc_3095', [
    CSN1Bit(name='profiles_list', bit=4),
    CSN1Bit(name='profile_instance', bit=2, num=([1], lambda x: x + 1)),
    CSN1Alt(alt={
      '0': ('', []),
      '1': ('', [
      CSN1Bit(name='uplink'),
      CSN1Bit(name='cid_inclusion_info'),
      CSN1Alt(alt={
        '0': ('', []),
        '1': ('', [
        CSN1Bit(name='max_cid', bit=14)])}),
      CSN1Alt(alt={
        '0': ('', []),
        '1': ('', [
        CSN1Bit(name='mrru', bit=16),
        CSN1Bit(name='packet_sizes_allowed_list', bit=4),
        CSN1Bit(name='packet_sizes_allowed', bit=11, num=([2], lambda x: x + 1))])})])}),
    CSN1Alt(alt={
      '0': ('', []),
      '1': ('', [
      CSN1Bit(name='downlink'),
      CSN1Bit(name='cid_inclusion_info'),
      CSN1Alt(alt={
        '0': ('', []),
        '1': ('', [
        CSN1Bit(name='max_cid', bit=14)])})])}),
    CSN1Alt(alt={
      '0': ('', []),
      '1': ('', [
      CSN1Bit(name='reverse_decompression_depth', bit=16)])})]),
    '010': ('pep', [])})])

pdcp_info_ie = CSN1List(name='pdcp_info_ie', list=[
  CSN1Bit(name='pdcp_mode'),
  CSN1Alt(alt={
    '0': ('lossless_serving_rnc_relocation_support', []),
    '1': ('lossless_serving_rnc_relocation_support', [
    CSN1Bit(name='max_pdcp_sn')])}),
  CSN1Bit(name='pdcp_pdu_header'),
  CSN1Bit(name='service_class', bit=4),
  CSN1Bit(name='pdu_type'),
  CSN1Alt(alt={
    '0': ('', []),
    '1': ('', [
    CSN1Bit(name='interactive_class_priority', bit=2)])}),
  CSN1Alt(alt={
    '0': ('support_for_pep', []),
    '1': ('support_for_pep', [
    CSN1Bit(name='support_for_pep_handover')])}),
  CSN1Alt(alt={
    '0': ('', []),
    '1': ('', [
    CSN1Bit(name='header_compression_information_list', bit=3),
    CSN1Ref(name='header_compression_information_struct', obj=header_compression_information_struct, num=([1], lambda x: x + 1))])}),
  CSN1Alt(alt={
    '0': ('data_compression_support', []),
    '1': ('data_compression_support', [
    CSN1Alt(alt={
      '0': ('', []),
      '1': ('', [
      CSN1Ref(name='downlink_data_compression_parameters', obj=data_compression_parameter_ie)])}),
    CSN1Alt(alt={
      '0': ('', []),
      '1': ('', [
      CSN1Ref(name='uplink_data_compression_parameters', obj=data_compression_parameter_ie)])})])})])

