# -*- coding: UTF-8 -*-
#/**
# * Software Name : pycrate
# * Version : 0.4
# *
# * Copyright 2018. Benoit Michau. P1sec.
# *
# * This library is free software; you can redistribute it and/or
# * modify it under the terms of the GNU Lesser General Public
# * License as published by the Free Software Foundation; either
# * version 2.1 of the License, or (at your option) any later version.
# *
# * This library is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# * Lesser General Public License for more details.
# *
# * You should have received a copy of the GNU Lesser General Public
# * License along with this library; if not, write to the Free Software
# * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
# * MA 02110-1301  USA
# *
# *--------------------------------------------------------
# * File Name : pycrate_gmr1_csn1/physical_channel_description_ie.py
# * Created : 2023-10-24
# * Authors : Benoit Michau
# *--------------------------------------------------------
#*/
# specification: ETSI TS 101 376-04-13
# section: 9.3.62a        Physical Channel Description
# top-level object: Physical Channel Description IE

# external references
from pycrate_gmr1_csn1.channel_info_ie import channel_info_ie
from pycrate_gmr1_csn1.slot_allocation_ie import slot_allocation_ie
from pycrate_gmr1_csn1.pdch_mcs_ie import dch_mcs_ie
from pycrate_gmr1_csn1.gmr_1_spotbeam_description_ie import gmr_1_spotbeam_description_ie
from pycrate_gmr1_csn1.packet_link_synchronization_parameters_ie import packet_link_synchronization_parameters_ie
from pycrate_gmr1_csn1.handover_reference_ie import handover_reference_ie

# code automatically generated by pycrate_csn1
# change object type with type=CSN1T_BSTR (default type is CSN1T_UINT) in init
# add dict for value interpretation with dic={...} in CSN1Bit init
# add dict for key interpretation with kdic={...} in CSN1Alt init

from pycrate_csn1.csnobj import *

directional_frequency_parameters_ie = CSN1List(name='directional_frequency_parameters_ie', list=[
  CSN1Bit(name='bandwidth', bit=3),
  CSN1Bit(name='arfcn', bit=11),
  CSN1Bit(name='reserved')])

handover_struct = CSN1List(name='handover_struct', list=[
  CSN1Ref(name='handover_reference', obj=handover_reference_ie),
  CSN1Alt(alt={
    '0': ('', []),
    '1': ('', [
    CSN1Ref(name='timing_advance', obj=packet_link_synchronization_parameters_ie)])}),
  CSN1Alt(alt={
    '0': ('', []),
    '1': ('', [
    CSN1Ref(name='gmr_1_spotbeam_description', obj=gmr_1_spotbeam_description_ie)])})])

physical_channel_description_ie = CSN1List(name='physical_channel_description_ie', list=[
  CSN1Val(name='', val='0'),
  CSN1Alt(alt={
    '0': ('', []),
    '1': ('', [
    CSN1Bit(name='power_control_parameter', bit=6)])}),
  CSN1Alt(alt={
    '0': ('', []),
    '1': ('', [
    CSN1Bit(name='power_control_synch_offset', bit=2)])}),
  CSN1Ref(name='dch_channel_mcs_info', obj=dch_mcs_ie),
  CSN1Ref(name='channel_info', obj=channel_info_ie),
  CSN1Alt(alt={
    '0': ('', [
    CSN1Bit(name='mac_slot_allocation', bit=8)]),
    '1': ('', [
    CSN1Ref(name='slot_allocation', obj=slot_allocation_ie)])}),
  CSN1Alt(alt={
    '0': ('', []),
    '1': ('', [
    CSN1Ref(name='frequency_parameters', obj=directional_frequency_parameters_ie)])})])

