# -*- coding: UTF-8 -*-
#/**
# * Software Name : pycrate
# * Version : 0.4
# *
# * Copyright 2018. Benoit Michau. P1sec.
# *
# * This library is free software; you can redistribute it and/or
# * modify it under the terms of the GNU Lesser General Public
# * License as published by the Free Software Foundation; either
# * version 2.1 of the License, or (at your option) any later version.
# *
# * This library is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# * Lesser General Public License for more details.
# *
# * You should have received a copy of the GNU Lesser General Public
# * License along with this library; if not, write to the Free Software
# * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
# * MA 02110-1301  USA
# *
# *--------------------------------------------------------
# * File Name : pycrate_gmr1_csn1/rab_binding_request_message_content.py
# * Created : 2023-10-24
# * Authors : Benoit Michau
# *--------------------------------------------------------
#*/
# specification: ETSI TS 101 376-04-13
# section: 9.2.26a RAB BINDING REQUEST
# top-level object: RAB BINDING REQUEST message content

# external references
from pycrate_gmr1_csn1.rab_identity_ie import rab_identity_ie
from pycrate_gmr1_csn1.integrity_check_info_ie import integrity_check_info_ie

# code automatically generated by pycrate_csn1
# change object type with type=CSN1T_BSTR (default type is CSN1T_UINT) in init
# add dict for value interpretation with dic={...} in CSN1Bit init
# add dict for key interpretation with kdic={...} in CSN1Alt init

from pycrate_csn1.csnobj import *

multicast_binding_info_struct = CSN1List(name='multicast_binding_info_struct', list=[
  CSN1Bit(name='multicast_group_id', bit=32),
  CSN1Bit(name='tunnel_port', bit=16),
  CSN1Bit(name='ipv4_pdp_address', bit=32),
  CSN1Val(name='', val='0')])

ptt_binding_info_struct = CSN1List(name='ptt_binding_info_struct', list=[
  CSN1Alt(alt={
    '0': ('', []),
    '1': ('', [
    CSN1Bit(name='ptt_session_key', bit=32)])}),
  CSN1Alt(alt={
    '0': ('', []),
    '1': ('', [
    CSN1Bit(name='ptt_session_mode', bit=2)])}),
  CSN1Val(name='', val='0')])

rab_binding_request_message_content = CSN1List(name='rab_binding_request_message_content', list=[
  CSN1Val(name='', val='0'),
  CSN1List(list=[
    CSN1Alt(alt={
      '0': ('', []),
      '1': ('', [
      CSN1Ref(name='integrity_check_info', obj=integrity_check_info_ie)])}),
    CSN1Ref(name='rab_id', obj=rab_identity_ie),
    CSN1Alt(alt={
      '00000': ('', [
      CSN1Ref(name='multicast_binding_info', obj=multicast_binding_info_struct)]),
      '00001': ('', []),
      '00010': ('', [
      CSN1Ref(name='ptt_binding_info', obj=ptt_binding_info_struct)]),
      '00011': ('', [
      CSN1Ref(name='ptt_binding_info', obj=ptt_binding_info_struct)]),
      '00100': ('', [])})])])

