# -*- coding: UTF-8 -*-
#/**
# * Software Name : pycrate
# * Version : 0.4
# *
# * Copyright 2018. Benoit Michau. P1sec.
# *
# * This library is free software; you can redistribute it and/or
# * modify it under the terms of the GNU Lesser General Public
# * License as published by the Free Software Foundation; either
# * version 2.1 of the License, or (at your option) any later version.
# *
# * This library is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# * Lesser General Public License for more details.
# *
# * You should have received a copy of the GNU Lesser General Public
# * License along with this library; if not, write to the Free Software
# * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
# * MA 02110-1301  USA
# *
# *--------------------------------------------------------
# * File Name : pycrate_gmr1_csn1/rrc_connection_setup_complete_message_content.py
# * Created : 2023-10-24
# * Authors : Benoit Michau
# *--------------------------------------------------------
#*/
# specification: ETSI TS 101 376-04-13
# section: 9.2.42          RRC CONNECTION SETUP COMPLETE
# top-level object: RRC CONNECTION SETUP COMPLETE message content

# external references
from pycrate_gmr1_csn1.gps_position_ie import gps_position_ie
from pycrate_gmr1_csn1.ue_software_version_indicator_ie import ue_software_version_indicator_ie
from pycrate_gmr1_csn1.cn_information_info_ie import cn_information_info_ie
from pycrate_gmr1_csn1.cn_domain_identity_ie import cn_domain_identity_ie
from pycrate_gmr1_csn1.rrc_transaction_identifier_ie import rrc_transaction_identifier_ie
from pycrate_gmr1_csn1.mes_geran_a_gb_mode_radio_access_capability_ie import mes_geran_a_gb_mode_radio_access_capability_ie
from pycrate_gmr1_csn1.start_ie import start_ie
from pycrate_gmr1_csn1.ue_utran_radio_access_capability_extension_ie import ue_utran_radio_access_capability_extension_ie
from pycrate_gmr1_csn1.ue_utran_radio_access_capability_ie import ue_utran_radio_access_capability_ie
from pycrate_gmr1_csn1.initial_mes_identity_ie import initial_mes_identity_ie
from pycrate_gmr1_csn1.ue_cdma2000_radio_access_capability_ie import ue_cdma2000_radio_access_capability_ie
from pycrate_gmr1_csn1.mes_geran_iu_mode_radio_access_capability_ie import mes_geran_iu_mode_radio_access_capability_ie

# code automatically generated by pycrate_csn1
# change object type with type=CSN1T_BSTR (default type is CSN1T_UINT) in init
# add dict for value interpretation with dic={...} in CSN1Bit init
# add dict for key interpretation with kdic={...} in CSN1Alt init

from pycrate_csn1.csnobj import *

spare_bits = CSN1Bit(name='spare_bits', num=-1)
Spare_bits = spare_bits
Spare_Bits = spare_bits

inter_rat_mes_radio_access_capability_struct = CSN1List(name='inter_rat_mes_radio_access_capability_struct', list=[
  CSN1Bit(name='inter_rat_mes_radio_access_capability_length', bit=15),
  CSN1Alt(alt={
    '0': ('', []),
    '1': ('', [
    CSN1Ref(name='mes_geran_a_gb_mode_radio_access_capability', obj=mes_geran_a_gb_mode_radio_access_capability_ie)])}),
  CSN1Alt(alt={
    '0': ('', []),
    '1': ('', [
    CSN1Ref(name='ue_utran_radio_access_capability', obj=ue_utran_radio_access_capability_ie)])}),
  CSN1Alt(alt={
    '0': ('', []),
    '1': ('', [
    CSN1Ref(name='ue_utran_radio_access_capability_extension', obj=ue_utran_radio_access_capability_extension_ie)])}),
  CSN1Alt(alt={
    '0': ('', []),
    '1': ('', [
    CSN1Ref(name='ue_cdma2000_radio_access_capability', obj=ue_cdma2000_radio_access_capability_ie)])}),
  CSN1Alt(alt={
    '0': ('', []),
    '1': ('', [
    CSN1Ref(name='ue_software_version_indicator', obj=ue_software_version_indicator_ie)])}),
  CSN1Ref(obj=spare_bits, num=-1)])

rrc_connection_setup_complete_message_content = CSN1List(name='rrc_connection_setup_complete_message_content', list=[
  CSN1Ref(name='rrc_transaction_identifier', obj=rrc_transaction_identifier_ie),
  CSN1Ref(name='initial_mes_identity', obj=initial_mes_identity_ie),
  CSN1Alt(alt={
    '0': ('', []),
    '1': ('', [
    CSN1Ref(name='mes_gps_position', obj=gps_position_ie)])}),
  CSN1Alt(alt={
    '0': ('', []),
    '1': ('', [
    CSN1Bit(name='gps_timestamp', bit=16)])}),
  CSN1Alt(alt={
    '0': ('', [
    CSN1Bit(name='directed_rac', bit=8)]),
    '1': ('', [
    CSN1Ref(name='cn_information_info', obj=cn_information_info_ie)])}),
  CSN1Bit(name='start_list', bit=2),
  CSN1List(num=([5], lambda x: x + 1), list=[
    CSN1Ref(name='cn_domain_identity', obj=cn_domain_identity_ie),
    CSN1Ref(name='start', obj=start_ie)]),
  CSN1Alt(alt={
    '0': ('', []),
    '1': ('', [
    CSN1Ref(name='mes_geran_iu_mode_radio_access_capability', obj=mes_geran_iu_mode_radio_access_capability_ie)])}),
  CSN1Ref(name='inter_rat_mes_radio_access_capability', obj=inter_rat_mes_radio_access_capability_struct)])

