# -*- coding: UTF-8 -*-
#/**
# * Software Name : pycrate
# * Version : 0.4
# *
# * Copyright 2018. Benoit Michau. P1sec.
# *
# * This library is free software; you can redistribute it and/or
# * modify it under the terms of the GNU Lesser General Public
# * License as published by the Free Software Foundation; either
# * version 2.1 of the License, or (at your option) any later version.
# *
# * This library is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# * Lesser General Public License for more details.
# *
# * You should have received a copy of the GNU Lesser General Public
# * License along with this library; if not, write to the Free Software
# * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
# * MA 02110-1301  USA
# *
# *--------------------------------------------------------
# * File Name : pycrate_gmr1_csn1/uplink_rrc_messages.py
# * Created : 2023-10-24
# * Authors : Benoit Michau
# *--------------------------------------------------------
#*/
# specification: ETSI TS 101 376-04-13
# section: 9.2.1.3             Uplink RRC messages
# top-level object: Uplink RRC messages

# external references
from pycrate_gmr1_csn1.security_mode_complete_message_content import security_mode_complete_message_content
from pycrate_gmr1_csn1.initial_direct_transfer_message_content import initial_direct_transfer_message_content
from pycrate_gmr1_csn1.rrc_status_message_content import rrc_status_message_content
from pycrate_gmr1_csn1.rab_upper_layer_reconfiguration_complete_message_content import rab_upper_layer_reconfiguration_complete_message_content
from pycrate_gmr1_csn1.mes_capability_information_message_content import mes_capability_information_message_content
from pycrate_gmr1_csn1.rab_binding_request_message_content import rab_binding_request_message_content
from pycrate_gmr1_csn1.radio_bearer_reconfiguration_failure_message_content import radio_bearer_reconfiguration_failure_message_content
from pycrate_gmr1_csn1.handover_complete_message_content import handover_complete_message_content
from pycrate_gmr1_csn1.radio_bearer_release_complete_message_content import radio_bearer_release_complete_message_content
from pycrate_gmr1_csn1.radio_bearer_release_failure_message_content import radio_bearer_release_failure_message_content
from pycrate_gmr1_csn1.rrc_connection_setup_complete_message_content import rrc_connection_setup_complete_message_content
from pycrate_gmr1_csn1.handover_failure_message_content import handover_failure_message_content
from pycrate_gmr1_csn1.uplink_direct_transfer_message_content import uplink_direct_transfer_message_content
from pycrate_gmr1_csn1.lcs_uplink_information_message_content import lcs_uplink_information_message_content
from pycrate_gmr1_csn1.geran_iu_mode_dtm_request_message_content import geran_iu_mode_dtm_request_message_content
from pycrate_gmr1_csn1.channel_change_preparation_complete_message_content import channel_change_preparation_complete_message_content
from pycrate_gmr1_csn1.rrc_connection_release_complete_message_content import rrc_connection_release_complete_message_content
from pycrate_gmr1_csn1.position_report_response_message_content import position_report_response_message_content
from pycrate_gmr1_csn1.position_update_indication_message_content import position_update_indication_message_content
from pycrate_gmr1_csn1.radio_bearer_reconfiguration_complete_message_content import radio_bearer_reconfiguration_complete_message_content
from pycrate_gmr1_csn1.geran_mobility_information_failure_message_content import geran_mobility_information_failure_message_content
from pycrate_gmr1_csn1.uplink_key_exchange_message_content import uplink_key_exchange_message_content
from pycrate_gmr1_csn1.radio_bearer_setup_complete_message_content import radio_bearer_setup_complete_message_content
from pycrate_gmr1_csn1.geran_mobility_information_confirm_message_content import geran_mobility_information_confirm_message_content
from pycrate_gmr1_csn1.security_mode_failure_message_content import security_mode_failure_message_content
from pycrate_gmr1_csn1.signalling_connection_release_indication_message_content import signalling_connection_release_indication_message_content
from pycrate_gmr1_csn1.measurement_report_message_content import measurement_report_message_content
from pycrate_gmr1_csn1.radio_bearer_setup_failure_message_content import radio_bearer_setup_failure_message_content

# code automatically generated by pycrate_csn1
# change object type with type=CSN1T_BSTR (default type is CSN1T_UINT) in init
# add dict for value interpretation with dic={...} in CSN1Bit init
# add dict for key interpretation with kdic={...} in CSN1Alt init

from pycrate_csn1.csnobj import *

spare_bits = CSN1Bit(name='spare_bits', num=-1)
Spare_bits = spare_bits
Spare_Bits = spare_bits

uplink_rrc_messages = CSN1Alt(name='uplink_rrc_messages', alt={
  '00000010': ('message_type', [
  CSN1Ref(obj=geran_mobility_information_confirm_message_content)]),
  '00000011': ('message_type', [
  CSN1Ref(obj=geran_mobility_information_failure_message_content)]),
  '00000101': ('message_type', [
  CSN1Ref(obj=uplink_key_exchange_message_content)]),
  '00000110': ('message_type', [
  CSN1Ref(obj=handover_complete_message_content)]),
  '00000111': ('message_type', [
  CSN1Ref(obj=handover_failure_message_content)]),
  '00001000': ('message_type', [
  CSN1Ref(obj=initial_direct_transfer_message_content)]),
  '00001001': ('message_type', [
  CSN1Ref(obj=lcs_uplink_information_message_content)]),
  '00001010': ('message_type', [
  CSN1Ref(obj=measurement_report_message_content)]),
  '00001011': ('message_type', [
  CSN1Ref(obj=mes_capability_information_message_content)]),
  '00001100': ('message_type', [
  CSN1Ref(obj=radio_bearer_reconfiguration_complete_message_content)]),
  '00001101': ('message_type', [
  CSN1Ref(obj=radio_bearer_reconfiguration_failure_message_content)]),
  '00001110': ('message_type', [
  CSN1Ref(obj=radio_bearer_release_complete_message_content)]),
  '00001111': ('message_type', [
  CSN1Ref(obj=radio_bearer_release_failure_message_content)]),
  '00010000': ('message_type', [
  CSN1Ref(obj=radio_bearer_setup_complete_message_content)]),
  '00010001': ('message_type', [
  CSN1Ref(obj=radio_bearer_setup_failure_message_content)]),
  '00010010': ('message_type', [
  CSN1Ref(obj=rrc_connection_release_complete_message_content)]),
  '00010100': ('message_type', [
  CSN1Ref(obj=rrc_connection_setup_complete_message_content)]),
  '00010101': ('message_type', [
  CSN1Ref(obj=rrc_status_message_content)]),
  '00010110': ('message_type', [
  CSN1Ref(obj=security_mode_complete_message_content)]),
  '00010111': ('message_type', [
  CSN1Ref(obj=security_mode_failure_message_content)]),
  '00011000': ('message_type', [
  CSN1Ref(obj=signalling_connection_release_indication_message_content)]),
  '00011001': ('message_type', [
  CSN1Ref(obj=uplink_direct_transfer_message_content)]),
  '00011010': ('message_type', [
  CSN1Ref(obj=rab_binding_request_message_content)]),
  '00011011': ('message_type', [
  CSN1Ref(obj=geran_iu_mode_dtm_request_message_content)]),
  '00011100': ('message_type', [
  CSN1Ref(obj=rab_upper_layer_reconfiguration_complete_message_content)]),
  '00011101': ('message_type', [
  CSN1Ref(obj=position_report_response_message_content)]),
  '00011110': ('message_type', [
  CSN1Ref(obj=channel_change_preparation_complete_message_content)]),
  '00011111': ('message_type', [
  CSN1Ref(obj=position_update_indication_message_content),
  CSN1Ref(obj=spare_bits, num=-1)])})

default_downlink_message_content = CSN1Bit(name='default_downlink_message_content', bit=-1)

