# -*- coding: UTF-8 -*-
#/**
# * Software Name : pycrate
# * Version : 0.4
# *
# * Copyright 2018. Benoit Michau. P1sec.
# *
# * This library is free software; you can redistribute it and/or
# * modify it under the terms of the GNU Lesser General Public
# * License as published by the Free Software Foundation; either
# * version 2.1 of the License, or (at your option) any later version.
# *
# * This library is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# * Lesser General Public License for more details.
# *
# * You should have received a copy of the GNU Lesser General Public
# * License along with this library; if not, write to the Free Software
# * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
# * MA 02110-1301  USA
# *
# *--------------------------------------------------------
# * File Name : pycrate_gmr1_csn1/zbhc_context_info_ie.py
# * Created : 2023-10-24
# * Authors : Benoit Michau
# *--------------------------------------------------------
#*/
# specification: ETSI TS 101 376-04-13
# section: 11.1.5.3a        ZBHC CONTEXT INFO
# top-level object: ZBHC Context Info IE

# external references
from pycrate_gmr1_csn1.rb_identity_ie import rb_identity_ie

# code automatically generated by pycrate_csn1
# change object type with type=CSN1T_BSTR (default type is CSN1T_UINT) in init
# add dict for value interpretation with dic={...} in CSN1Bit init
# add dict for key interpretation with kdic={...} in CSN1Alt init

from pycrate_csn1.csnobj import *

zbhc_context_ie = CSN1List(name='zbhc_context_ie', list=[
  CSN1Alt(alt={
    '0': ('', [
    CSN1Bit(name='dscp', bit=6),
    CSN1Bit(name='ecn', bit=2),
    CSN1Bit(name='source_ipv4_address', bit=32),
    CSN1Bit(name='destination_ipv4_address', bit=32),
    CSN1Bit(name='ipv4_identifier', bit=16)]),
    '1': ('', [
    CSN1Bit(name='traffic_class', bit=8),
    CSN1Bit(name='flow_label', bit=20),
    CSN1Bit(name='source_ipv6_address', bit=128),
    CSN1Bit(name='destination_ipv6_address', bit=128)])}),
  CSN1Bit(name='source_udp_port', bit=16),
  CSN1Bit(name='destination_udp_port', bit=16),
  CSN1Bit(name='rtp_version', bit=2),
  CSN1Bit(name='rtp_payload_type', bit=7),
  CSN1Bit(name='rtp_ssrc', bit=32),
  CSN1Bit(name='rtp_sequence', bit=16),
  CSN1Bit(name='rtp_timestamp', bit=32),
  CSN1Bit(name='last_frame_number', bit=22)])

zbhc_context_info_ie = CSN1List(name='zbhc_context_info_ie', list=[
  CSN1Bit(name='rb_with_zbhc_context_list', bit=5),
  CSN1List(num=([0], lambda x: x + 1), list=[
    CSN1Ref(name='rb_identity', obj=rb_identity_ie),
    CSN1Alt(alt={
      '0': ('', []),
      '1': ('', [
      CSN1Ref(name='uplink_zbhc_context', obj=zbhc_context_ie)])})])])

